<?php
/**
 * Navigation Functions
 * @package Zurbox Lite
 * @link http://codex.wordpress.org/Function_Reference/wp_nav_menu
 */


/**
 * Desktop navigation - right top bar
 */
if ( ! function_exists( 'zurbox_topbar_r' ) ) {
	function zurbox_topbar_r() {
		wp_nav_menu( array(
			'container'      => false,
			'menu_class'     => 'dropdown menu',
			'items_wrap'     => '<ul id="%1$s" class="%2$s show-for-medium" data-dropdown-menu>%3$s</ul>',
			'theme_location' => 'top-bar-r',
			'depth'          => 4,
			'fallback_cb'    => false,
			'walker'         => new Zurbox_Top_Bar_Walker(),
		));
	}
}

/**
 * Desktop navigation - left top bar
 */
if ( ! function_exists( 'zurbox_topbar_l' ) ) {
	function zurbox_topbar_l() {
		wp_nav_menu( array(
			'container'      => false,
			'menu_class'     => 'dropdown menu',
			'items_wrap'     => '<ul id="%1$s" class="%2$s show-for-medium" data-dropdown-menu>%3$s</ul>',
			'theme_location' => 'top-bar-l',
			'depth'          => 4,
			'fallback_cb'    => false,
			'walker'         => new Zurbox_Top_Bar_Walker(),
		));
	}
}


/**
 * Mobile navigation - topbar (default) or offcanvas
 */
if ( ! function_exists( 'zurbox_mobile_nav' ) ) {
	function zurbox_mobile_nav() {
		wp_nav_menu( array(
			'container'      => false, // Remove nav container
			'menu'           => esc_html( 'mobile-nav' ),
			'menu_class'     => 'vertical menu',
			'theme_location' => 'mobile-nav',
			'items_wrap'     => '<ul id="%1$s" class="%2$s show-for-small-only" data-accordion-menu>%3$s</ul>',
			'fallback_cb'    => false,
			'walker'         => new Zurbox_Mobile_Walker(),
		));
	}
}


/**
 * Add support for buttons in the top-bar menu
 */
if ( ! function_exists( 'zurbox_add_menuclass' ) ) {
	function zurbox_add_menuclass( $ulclass ) {
		$find = array('/<a rel="button"/', '/<a title=".*?" rel="button"/');
		$replace = array('<a rel="button" class="button"', '<a rel="button" class="button"');

		return preg_replace( $find, $replace, $ulclass, 1 );
	}
	add_filter( 'wp_nav_menu','zurbox_add_menuclass' );
}


/**
 * Adapted from http://thewebtaylor.com/articles/wordpress-creating-breadcrumbs-without-a-plugin
 *
 * @param bool $showhome should the breadcrumb be shown when on homepage (only one deactivated entry for home).
 * @param bool $separatorclass should a separator class be added (in case :before is not an option).
 */
if ( ! function_exists( 'zurbox_breadcrumb' ) ) {
	function zurbox_breadcrumb( $showhome = true, $separatorclass = false ) {

		// Settings
		$separator  = '&gt;';
		$id         = 'breadcrumbs';
		$class      = 'breadcrumbs';
		$home_title = esc_html__( 'Home', 'zurbox-lite' );

		// Get the query & post information
		global $post,$wp_query;
		$category = get_the_category();

		// Build the breadcrums
		echo '<ul id="' . $id . '" class="' . $class . '">';

		// Do not display on the homepage
		if ( ! is_front_page() ) {

			// Home page
			echo '<li class="item-home"><a class="bread-link bread-home" href="' . esc_url( get_home_url() ) . '" title="' . $home_title . '">' . $home_title . '</a></li>';
			if ( $separatorclass ) {
				echo '<li class="separator separator-home"> ' . $separator . ' </li>';
			}

			if ( is_single() && isset($category[0]) ) {

				// Single post (Only display the first category)
				echo '<li class="item-cat item-cat-' . $category[0]->term_id . ' item-cat-' . $category[0]->category_nicename . '"><a class="bread-cat bread-cat-' . $category[0]->term_id . ' bread-cat-' . $category[0]->category_nicename . '" href="' . get_category_link($category[0]->term_id) . '" title="' . $category[0]->cat_name . '">' . $category[0]->cat_name . '</a></li>';
				if ( $separatorclass ) {
					echo '<li class="separator separator-' . $category[0]->term_id . '"> ' . $separator . ' </li>';
				}
				echo '<li class="item-current item-' . $post->ID . '"><strong class="bread-current bread-' . $post->ID . '" title="' . get_the_title() . '">' . get_the_title() . '</strong></li>';

			} else if ( is_category() && isset($category[0]) ) {

				// Category page
				echo '<li class="item-current item-cat-' . $category[0]->term_id . ' item-cat-' . $category[0]->category_nicename . '"><strong class="bread-current bread-cat-' . $category[0]->term_id . ' bread-cat-' . $category[0]->category_nicename . '">' . $category[0]->cat_name . '</strong></li>';

			} else if ( is_page() ) {

				// Standard page
				if ( $post->post_parent ) {

					// If child page, get parents
					$anc = get_post_ancestors( $post->ID );

					// Get parents in the right order
					$anc = array_reverse( $anc );

					// Parent page loop
					$parents = '';
					foreach ( $anc as $ancestor ) {
						$parents .= '<li class="item-parent item-parent-' . $ancestor . '"><a class="bread-parent bread-parent-' . $ancestor . '" href="' . get_permalink($ancestor) . '" title="' . get_the_title($ancestor) . '">' . get_the_title($ancestor) . '</a></li>';
						if ( $separatorclass ) {
							$parents .= '<li class="separator separator-' . $ancestor . '"> ' . $separator . ' </li>';
						}
					}

					// Display parent pages
					echo $parents;

					// Current page
					echo '<li class="current item-' . $post->ID . '">' . get_the_title() . '</li>';

				} else {

					// Just display current page if not parents
					echo '<li class="current item-' . $post->ID . '"> ' . get_the_title() . '</li>';

				}
			} else if ( is_post_type_archive() ) {
				// Post Type Archive page
				$post_type = get_post_type_object( get_post_type() );
				echo '<li class="item-current"><strong class="bread-current">' . $post_type->label . '</strong></li>';

			} else if ( is_single() && 'post' != get_post_type() ) {
				// Post Type single
				$post_type = get_post_type_object( get_post_type() );
				echo '<li class="item-type"><a class="bread-cat" href="' . get_post_type_archive_link( get_post_type() ) . '">' . $post_type->label . '</a>';
				if ( $separatorclass ) {
					echo '<li class="separator"> ' . $separator . ' </li>';
				}
				echo '<li class="item-current"><strong class="bread-current">' . get_the_title() . '</strong></li>';

			} else if ( is_tax() && 'post' != get_post_type() ) {
				$post_type = get_post_type_object( get_post_type() );
				echo '<li class="item-type"><a class="bread-cat" href="' . get_post_type_archive_link( get_post_type() ) . '">' . $post_type->label . '</a>';

			} else if ( is_tag() ) {

				// Tag page
				// Get tag information
				$term_id = get_query_var('tag_id');
				$taxonomy = 'post_tag';
				$args = 'include=' . $term_id;
				$terms = get_terms($taxonomy, $args);

				// Display the tag name
				echo '<li class="current item-tag-' . $terms[0]->term_id . ' item-tag-' . $terms[0]->slug . '">' . $terms[0]->name . '</li>';

			} elseif ( is_day() ) {

				// Day archive
				// Year link
				echo '<li class="item-year item-year-' . get_the_time('Y') . '"><a class="bread-year bread-year-' . get_the_time('Y') . '" href="' . get_year_link(get_the_time('Y')) . '" title="' . get_the_time('Y') . '">' . get_the_time('Y') . ' Archives</a></li>';
				if ( $separatorclass ) {
					echo '<li class="separator separator-' . get_the_time('Y') . '"> ' . $separator . ' </li>';
				}

				// Month link
				echo '<li class="item-month item-month-' . get_the_time('m') . '"><a class="bread-month bread-month-' . get_the_time('m') . '" href="' . get_month_link(get_the_time('Y'), get_the_time('m')) . '" title="' . get_the_time('M') . '">' . get_the_time('M') . '</a></li>';
				if ( $separatorclass ) {
					echo '<li class="separator separator-' . get_the_time('m') . '"> ' . $separator . ' </li>';
				}

				// Day display
				echo '<li class="current item-' . get_the_time('j') . '">' . get_the_time('jS') . ' ' . get_the_time('M') . '</li>';

			} else if ( is_month() ) {

				// Month Archive
				// Year link
				echo '<li class="item-year item-year-' . get_the_time('Y') . '"><a class="bread-year bread-year-' . get_the_time('Y') . '" href="' . get_year_link(get_the_time('Y')) . '" title="' . get_the_time('Y') . '">' . get_the_time('Y') . '</a></li>';
				if ( $separatorclass ) {
					echo '<li class="separator separator-' . get_the_time('Y') . '"> ' . $separator . ' </li>';
				}

				// Month display
				echo '<li class="item-month item-month-' . get_the_time('m') . '">' . get_the_time('M') . '</li>';

			} else if ( is_year() ) {

				// Display year archive
				echo '<li class="current item-current-' . get_the_time('Y') . '">' . get_the_time('Y') . '</li>';

			} else if ( is_author() ) {

				// Auhor archive
				// Get the author information
				global $author;
				$userdata = get_userdata($author);

				// Display author name
				echo '<li class="current item-current-' . $userdata->user_nicename . '">' . esc_html__( 'Author:', 'zurbox-lite' ) . $userdata->display_name . '</li>';

			} else if ( get_query_var('paged') ) {

				// Paginated archives
				echo '<li class="current item-current-' . get_query_var('paged') . '">' . esc_html__( 'Page', 'zurbox-lite' ) . ' ' . get_query_var('paged') . '</li>';

			} else if ( is_search() ) {

				// Search results page
				echo '<li class="current item-current-' . get_search_query() . '">' . esc_html__( 'Search Reasults for: ', 'zurbox-lite' ) . get_search_query() . '</li>';

			} elseif ( is_404() ) {

				// 404 page
				echo '<li>' . esc_html__( 'Error 404', 'zurbox-lite' ) . '</li>';
			}
		} else {
			if ( $showhome ) {
				echo '<li class="item-home current">' . $home_title . '</li>';
			}
		}
		echo '</ul>';
	}
}